pitchtools.is_diatonic_pitch_class_number
=========================================

.. autofunction:: abjad.tools.pitchtools.is_diatonic_pitch_class_number.is_diatonic_pitch_class_number
   :noindex:
